Imported from libpng-1.4.0beta2.tar
diff --git a/png.h b/png.h
index 2b8ff29..faf22a4 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.4.0beta1 - April 20, 2006
  * Copyright (c) 1998-2006 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -9,7 +9,7 @@
  * Authors and maintainers:
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
  *  libpng versions 0.97, January 1998, through 1.4.0beta1 - April 20, 2006: Glenn
  *  See also "Contributing Authors", below.
  *
  * Note about libpng version numbers:
@@ -116,9 +116,9 @@
  *    1.2.9beta4-11           13    10209  12.so.0.9[.0]
  *    1.2.9rc1                13    10209  12.so.0.9[.0]
  *    1.2.9                   13    10209  12.so.0.9[.0]
- *    1.2.10beta1-8           13    10210  12.so.0.10[.0]
+ *    1.2.10beta1-7           13    10210  12.so.0.10[.0]
  *    1.2.10rc1-2             13    10210  12.so.0.10[.0]
- *    1.4.0beta1              14    10401  14.so.0.0[.0]
+ *    1.4.0beta1-2            14    10400  14.so.0.0[.0]
  *
  *    Henceforth the source version will match the shared-library major
  *    and minor numbers; the shared-library major version number will be
@@ -148,7 +148,7 @@
  * If you modify libpng you may insert additional notices immediately following
  * this sentence.
  *
  * libpng versions 1.2.6, August 15, 2004, through 1.4.0beta1, April 20, 2006, are
  * Copyright (c) 2004, 2006 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
  * with the following individual added to the list of Contributing Authors:
@@ -260,13 +260,13 @@
  * Y2K compliance in libpng:
  * =========================
  *
- *    April 20, 2006
+ *    April 21, 2006
  *
  *    Since the PNG Development group is an ad-hoc body, we can't make
  *    an official declaration.
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
  *    upward through 1.4.0beta1 are Y2K compliant.  It is my belief that earlier
  *    versions were also Y2K compliant.
  *
  *    Libpng only has three year fields.  One is a 2-byte unsigned integer
@@ -322,9 +322,9 @@
  */
 
 /* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.4.0beta1"
+#define PNG_LIBPNG_VER_STRING "1.4.0beta2"
 #define PNG_HEADER_VERSION_STRING \
-   " libpng version 1.4.0beta1 - April 20, 2006 (header)\n"
+   " libpng version 1.4.0beta2 - April 21, 2006 (header)\n"
 
 #define PNG_LIBPNG_VER_SONUM   0
 #define PNG_LIBPNG_VER_DLLNUM  14
@@ -336,7 +336,7 @@
 /* This should match the numeric part of the final component of
  * PNG_LIBPNG_VER_STRING, omitting any leading zero: */
 
-#define PNG_LIBPNG_VER_BUILD  1
+#define PNG_LIBPNG_VER_BUILD  2
 
 /* Release Status */
 #define PNG_LIBPNG_BUILD_ALPHA    1
@@ -463,7 +463,7 @@
 PNG_EXPORT_VAR (const int FARDATA) png_pass_yinc[7];
 PNG_EXPORT_VAR (const int FARDATA) png_pass_mask[7];
 PNG_EXPORT_VAR (const int FARDATA) png_pass_dsp_mask[7];
-#ifdef PNG_HAVE_MMX_COMBINE_ROW
+#ifdef PNG_USE_PNGGCCRD
 PNG_EXPORT_VAR (const int FARDATA) png_pass_width[7];
 #endif
 /* This isn't currently used.  If you need it, see png.c for more details.
@@ -1360,7 +1360,7 @@
 /* This triggers a compiler error in png.c, if png.c and png.h
  * do not agree upon the version number.
  */
-typedef png_structp version_1_4_0beta1;
+typedef png_structp version_1_4_0beta2;
 
 typedef png_struct FAR * FAR * png_structpp;
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.4.0beta1 - April 20, 2006
+ * libpng version 1.4.0beta2 - April 21, 2006
  * Copyright (c) 1998-2006 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -9,7 +9,7 @@
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- *  libpng versions 0.97, January 1998, through 1.4.0beta1 - April 20, 2006: Glenn
+ *  libpng versions 0.97, January 1998, through 1.4.0beta2 - April 21, 2006: Glenn
  *  See also "Contributing Authors", below.
  *
@@ -148,7 +148,7 @@
  * this sentence.
  *
- * libpng versions 1.2.6, August 15, 2004, through 1.4.0beta1, April 20, 2006, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.4.0beta2, April 21, 2006, are
  * Copyright (c) 2004, 2006 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
@@ -260,13 +260,13 @@
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
- *    upward through 1.4.0beta1 are Y2K compliant.  It is my belief that earlier
+ *    upward through 1.4.0beta2 are Y2K compliant.  It is my belief that earlier
  *    versions were also Y2K compliant.
  *